FMRIPREP: A Robust Preprocessing Pipeline for fMRI Data
=======================================================

This pipeline is developed by the Poldrack lab at Stanford University (https://poldracklab.stanford.edu/) for use at the Center for Reproducible Neuroscience (http://reproducibility.stanford.edu/), as well as for open-source software distribution.

.. image:: https://circleci.com/gh/poldracklab/preprocessing-workflow/tree/master.svg?style=shield
  :target: https://circleci.com/gh/poldracklab/preprocessing-workflow/tree/master
  
.. image:: https://readthedocs.org/projects/preprocessing-workflow/badge/?version=latest
  :target: http://preprocessing-workflow.readthedocs.io/en/latest/?badge=latest
  :alt: Documentation Status

Reporting Issues
----------------

All bugs, concerns and enhancement requests for this software can be submitted here:

https://github.com/poldracklab/preprocessing-workflow/issues.


Authors
-------

The authors of preprocessing-workflow can be found `here <AUTHORS>`_.

License
-------

Preprocessing-workflow is licensed under the Revised BSD Licence. The license can be found `here <LICENSE>`_.
